import json
from glob import glob
from time import time_ns
import os
from collections import OrderedDict
from sys import argv

home = os.path.expanduser("~/.bink")
max_title_length = 120
max_body_length = 64_000

try:
    os.mkdir(home)
except FileExistsError:
    pass

def write_object(obj):
    with open(f"{home}/{time_ns()}", "w") as f:
        json.dump(obj, f, indent=2)

def file_object(path):
    split = path.split("/")
    # example input: /home/nebula/.bink/999
    # output: (999, "nebula", "/home/nebula/.bink/999")
    return (int(split[-1]), split[2], path)

def create_forum_post(title, body):
    thread = {
        "body": body[:max_body_length],
        "forum": title[:max_title_length]
    }
    write_object(thread)

def create_blog_post(body):
    blog = {
        "body": body,
        "forum": False
    }
    write_object(blog)

def generate_feed():
    posts = [file_object(path) for path in glob("/home/**/.bink/*")]
    posts.sort(key=lambda x: x[0], reverse=True)
    forums = OrderedDict()
    blogs = []
    for time, user, path in posts:
        # try:
        with open(path, "r") as f:
            data = json.load(f)
        # except
        obj = {
            "user": user,
            "time": time,
            "body": data["body"][:max_body_length],
            "forum": data["forum"]
        }
        if obj["forum"]:
            obj["forum"] = obj["forum"][:max_title_length]
            try:
                forums[data["forum"]].insert(0, obj)
            except KeyError:
                forums[data["forum"]] = [obj]
        else:
            blogs.insert(0, obj)
    return (blogs, forums)

if "dump" in argv:
    with open("/dev/stdout", "w") as f:
        json.dump(generate_feed(), f)
    exit()

import urwid